@@ -47,13 +47,19 @@ Examples:
 	$ smug print > ~/.config/smug/blog.yml
 `, version, FileUsage, WindowsUsage, AttachUsage, InsideCurrentSessionUsage, DebugUsage, DetachUsage)
 
-func main() {
-	options, err := ParseOptions(os.Args[1:], func() {
-		fmt.Fprintf(os.Stdout, usage)
-		os.Exit(0)
-	})
+func newLogger(path string) *log.Logger {
+	logFile, err := os.Create(filepath.Join(path, "smug.log"))
+	if err != nil {
+		fmt.Fprintln(os.Stderr, err.Error())
+		os.Exit(1)
+	}
+	return log.New(logFile, "", 0)
+}
 
+func main() {
+	options, err := ParseOptions(os.Args[1:])
 	if err == ErrHelp {
+		fmt.Fprint(os.Stdout, usage)
 		os.Exit(0)
 	}
 
@@ -70,12 +76,7 @@ func main() {
 
 	var logger *log.Logger
 	if options.Debug {
-		logFile, err := os.Create(filepath.Join(userConfigDir, "smug.log"))
-		if err != nil {
-			fmt.Fprintln(os.Stderr, err.Error())
-			os.Exit(1)
-		}
-		logger = log.New(logFile, "", 0)
+		logger = newLogger(userConfigDir)
 	}
 
 	commander := DefaultCommander{logger}
@@ -86,15 +87,8 @@ func main() {
 	var configPath string
 	if options.Config != "" {
 		configPath = options.Config
-	} else if options.Project != "" {
-		configPath = filepath.Join(userConfigDir, options.Project+".yml")
 	} else {
-		s, err := tmux.SessionName()
-		if err != nil {
-			fmt.Fprintln(os.Stderr, err.Error())
-			os.Exit(1)
-		}
-		configPath = filepath.Join(userConfigDir, s+".yml")
+		configPath = filepath.Join(userConfigDir, options.Project+".yml")
 	}
 
 	switch options.Command {
@@ -106,7 +100,7 @@ func main() {
 		}
 		config, err := GetConfig(configPath, options.Settings)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, err.Error())
+			fmt.Fprint(os.Stderr, err.Error())
 			os.Exit(1)
 		}
 
@@ -124,25 +118,25 @@ func main() {
 		}
 		config, err := GetConfig(configPath, options.Settings)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, err.Error())
+			fmt.Fprint(os.Stderr, err.Error())
 			os.Exit(1)
 		}
 
 		err = smug.Stop(config, options, context)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, err.Error())
+			fmt.Fprint(os.Stderr, err.Error())
 			os.Exit(1)
 		}
 	case CommandNew, CommandEdit:
 		err := EditConfig(configPath)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, err.Error())
+			fmt.Fprint(os.Stderr, err.Error())
 			os.Exit(1)
 		}
 	case CommandList:
 		configs, err := ListConfigs(userConfigDir)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, err.Error())
+			fmt.Fprint(os.Stderr, err.Error())
 			os.Exit(1)
 		}
 
@@ -150,13 +144,13 @@ func main() {
 	case CommandPrint:
 		config, err := smug.GetConfigFromSession(options, context)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, err.Error())
+			fmt.Fprint(os.Stderr, err.Error())
 			os.Exit(1)
 		}
 
 		d, err := yaml.Marshal(&config)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, err.Error())
+			fmt.Fprint(os.Stderr, err.Error())
 			os.Exit(1)
 		}
 
